@@ -88,7 +88,7 @@ class CustomTxType:
     UtxosToAccount:str = 'U'
     AccountToUtxos:str = 'b'
     AccountToAccount:str = 'B'
-    AnyAccountsToAccounts = 'a'
+    AnyAccountsToAccounts:str = 'a'
     SmartContract:str = 'K'
     DFIP2203:str = 'Q'
     # set governance variable
