@@ -22,6 +22,10 @@ def decodeCustomTx(hex):
         res = decodePoolSwapV2(hex[2:])
         if res != None:
             res['name'] = 'compositeswap'
+    elif functionMarker == 'Q':
+        res = decodeDFIP2203(hex[2:])
+        if res != None:
+            res['name'] = 'dfip2203'
     elif functionMarker == 'l':
         res = decodeAddPoolLiquidity(hex[2:])
         if res != None:
@@ -153,6 +157,16 @@ def decodePoolSwapV2(hex):
         }
     ]
     return searchHex(variables,hex)
+def decodeDFIP2203(hex):
+    variables = [
+        {'key': 'from', 'type': 'address','endian':None},
+        {'bytesCount':1, 'key': 'fromTokenId', 'type': int,'endian':None},
+        {'bytesCount': 8, 'key': 'fromAmount', 'type': int,'endian':'little'},
+        {'bytesCount':1, 'key': 'toTokenId', 'type': int,'endian':None},
+        {'bytesCount':4, 'key': 'direction', 'type': int,'endian':None}
+    ]
+    return searchHex(variables,hex)
+    
 def decodeAddPoolLiquidity(hex):
     variables = [
         {'key':'addresses', 'type': [
@@ -291,6 +305,8 @@ def decodeDepositToVault(hex):
         {'bytesCount': 8,'key': 'amount', 'type': int,'endian':'little'}
     ]
     return searchHex(variables,hex)
+
+    
 def recursiveSearchHex(variable,hex):
     abort = False
     if type(variable['type']) == list:
